==> CRM64Pro-0.14.0-docs.zip: CRM64Pro-0.14.0-docs/html/annotated_dup.js <==
var annotated_dup =
[
    [ "CRM64Pro", "namespace_c_r_m64_pro.html", [
      [ "Position", "struct_c_r_m64_pro_1_1_position.html", "struct_c_r_m64_pro_1_1_position" ],
      [ "Main", "class_c_r_m64_pro_1_1_main.html", "class_c_r_m64_pro_1_1_main" ],
      [ "Log", "class_c_r_m64_pro_1_1_log.html", "class_c_r_m64_pro_1_1_log" ],
      [ "LogMgr", "class_c_r_m64_pro_1_1_log_mgr.html", "class_c_r_m64_pro_1_1_log_mgr" ],
      [ "Screen", "class_c_r_m64_pro_1_1_screen.html", "class_c_r_m64_pro_1_1_screen" ],
      [ "ConfigMgr", "class_c_r_m64_pro_1_1_config_mgr.html", "class_c_r_m64_pro_1_1_config_mgr" ],
      [ "Archive", "class_c_r_m64_pro_1_1_archive.html", "class_c_r_m64_pro_1_1_archive" ],
      [ "ArchiveMgr", "class_c_r_m64_pro_1_1_archive_mgr.html", "class_c_r_m64_pro_1_1_archive_mgr" ],
      [ "XML", "class_c_r_m64_pro_1_1_x_m_l.html", "class_c_r_m64_pro_1_1_x_m_l" ],
      [ "XMLMgr", "class_c_r_m64_pro_1_1_x_m_l_mgr.html", "class_c_r_m64_pro_1_1_x_m_l_mgr" ],
      [ "Timer", "class_c_r_m64_pro_1_1_timer.html", "class_c_r_m64_pro_1_1_timer" ],
      [ "Tool", "class_c_r_m64_pro_1_1_tool.html", "class_c_r_m64_pro_1_1_tool" ],
      [ "AudioInfo", "struct_c_r_m64_pro_1_1_audio_info.html", "struct_c_r_m64_pro_1_1_audio_info" ],
      [ "AudioTrack", "class_c_r_m64_pro_1_1_audio_track.html", "class_c_r_m64_pro_1_1_audio_track" ],
      [ "AudioTrackMgr", "class_c_r_m64_pro_1_1_audio_track_mgr.html", "class_c_r_m64_pro_1_1_audio_track_mgr" ],
      [ "Image", "class_c_r_m64_pro_1_1_image.html", "class_c_r_m64_pro_1_1_image" ],
      [ "ImageMgr", "class_c_r_m64_pro_1_1_image_mgr.html", "class_c_r_m64_pro_1_1_image_mgr" ],
      [ "Cursor", "class_c_r_m64_pro_1_1_cursor.html", "class_c_r_m64_pro_1_1_cursor" ],
      [ "CursorMgr", "class_c_r_m64_pro_1_1_cursor_mgr.html", "class_c_r_m64_pro_1_1_cursor_mgr" ],
      [ "Tile", "class_c_r_m64_pro_1_1_tile.html", "class_c_r_m64_pro_1_1_tile" ],
      [ "TileMgr", "class_c_r_m64_pro_1_1_tile_mgr.html", "class_c_r_m64_pro_1_1_tile_mgr" ],
      [ "Sprite", "class_c_r_m64_pro_1_1_sprite.html", "class_c_r_m64_pro_1_1_sprite" ],
      [ "SpriteMgr", "class_c_r_m64_pro_1_1_sprite_mgr.html", "class_c_r_m64_pro_1_1_sprite_mgr" ],
      [ "Font", "class_c_r_m64_pro_1_1_font.html", "class_c_r_m64_pro_1_1_font" ],
      [ "FontMgr", "class_c_r_m64_pro_1_1_font_mgr.html", "class_c_r_m64_pro_1_1_font_mgr" ],
      [ "GFX", "class_c_r_m64_pro_1_1_g_f_x.html", "class_c_r_m64_pro_1_1_g_f_x" ],
      [ "Widget", "class_c_r_m64_pro_1_1_widget.html", "class_c_r_m64_pro_1_1_widget" ],
      [ "Panel", "class_c_r_m64_pro_1_1_panel.html", "class_c_r_m64_pro_1_1_panel" ],
      [ "Console", "class_c_r_m64_pro_1_1_console.html", "class_c_r_m64_pro_1_1_console" ],
      [ "DebugWindow", "class_c_r_m64_pro_1_1_debug_window.html", "class_c_r_m64_pro_1_1_debug_window" ],
      [ "GUIMgr", "class_c_r_m64_pro_1_1_g_u_i_mgr.html", "class_c_r_m64_pro_1_1_g_u_i_mgr" ],
      [ "TE_MapData", "class_c_r_m64_pro_1_1_t_e___map_data.html", "class_c_r_m64_pro_1_1_t_e___map_data" ],
      [ "TileEngine", "class_c_r_m64_pro_1_1_tile_engine.html", "class_c_r_m64_pro_1_1_tile_engine" ],
      [ "TileEngineMgr", "class_c_r_m64_pro_1_1_tile_engine_mgr.html", "class_c_r_m64_pro_1_1_tile_engine_mgr" ],
      [ "NetTCP", "class_c_r_m64_pro_1_1_net_t_c_p.html", "class_c_r_m64_pro_1_1_net_t_c_p" ]
    ] ]
];

==> CRM64Pro-0.15.0-docs.zip: CRM64Pro-0.15.0-docs/html/annotated_dup.js <==
var annotated_dup =
[
    [ "CRM64Pro", "namespace_c_r_m64_pro.html", [
      [ "Position", "struct_c_r_m64_pro_1_1_position.html", "struct_c_r_m64_pro_1_1_position" ],
      [ "Main", "class_c_r_m64_pro_1_1_main.html", "class_c_r_m64_pro_1_1_main" ],
      [ "Log", "class_c_r_m64_pro_1_1_log.html", "class_c_r_m64_pro_1_1_log" ],
      [ "LogMgr", "class_c_r_m64_pro_1_1_log_mgr.html", "class_c_r_m64_pro_1_1_log_mgr" ],
      [ "Screen", "class_c_r_m64_pro_1_1_screen.html", "class_c_r_m64_pro_1_1_screen" ],
      [ "ConfigMgr", "class_c_r_m64_pro_1_1_config_mgr.html", "class_c_r_m64_pro_1_1_config_mgr" ],
      [ "Archive", "class_c_r_m64_pro_1_1_archive.html", "class_c_r_m64_pro_1_1_archive" ],
      [ "ArchiveMgr", "class_c_r_m64_pro_1_1_archive_mgr.html", "class_c_r_m64_pro_1_1_archive_mgr" ],
      [ "XML", "class_c_r_m64_pro_1_1_x_m_l.html", "class_c_r_m64_pro_1_1_x_m_l" ],
      [ "XMLMgr", "class_c_r_m64_pro_1_1_x_m_l_mgr.html", "class_c_r_m64_pro_1_1_x_m_l_mgr" ],
      [ "Timer", "class_c_r_m64_pro_1_1_timer.html", "class_c_r_m64_pro_1_1_timer" ],
      [ "Tool", "class_c_r_m64_pro_1_1_tool.html", "class_c_r_m64_pro_1_1_tool" ],
      [ "AudioInfo", "struct_c_r_m64_pro_1_1_audio_info.html", "struct_c_r_m64_pro_1_1_audio_info" ],
      [ "AudioTrack", "class_c_r_m64_pro_1_1_audio_track.html", "class_c_r_m64_pro_1_1_audio_track" ],
      [ "AudioTrackMgr", "class_c_r_m64_pro_1_1_audio_track_mgr.html", "class_c_r_m64_pro_1_1_audio_track_mgr" ],
      [ "Image", "class_c_r_m64_pro_1_1_image.html", "class_c_r_m64_pro_1_1_image" ],
      [ "ImageMgr", "class_c_r_m64_pro_1_1_image_mgr.html", "class_c_r_m64_pro_1_1_image_mgr" ],
      [ "Cursor", "class_c_r_m64_pro_1_1_cursor.html", "class_c_r_m64_pro_1_1_cursor" ],
      [ "CursorMgr", "class_c_r_m64_pro_1_1_cursor_mgr.html", "class_c_r_m64_pro_1_1_cursor_mgr" ],
      [ "Tile", "class_c_r_m64_pro_1_1_tile.html", "class_c_r_m64_pro_1_1_tile" ],
      [ "TileMgr", "class_c_r_m64_pro_1_1_tile_mgr.html", "class_c_r_m64_pro_1_1_tile_mgr" ],
      [ "Sprite", "class_c_r_m64_pro_1_1_sprite.html", "class_c_r_m64_pro_1_1_sprite" ],
      [ "SpriteMgr", "class_c_r_m64_pro_1_1_sprite_mgr.html", "class_c_r_m64_pro_1_1_sprite_mgr" ],
      [ "Font", "class_c_r_m64_pro_1_1_font.html", "class_c_r_m64_pro_1_1_font" ],
      [ "FontMgr", "class_c_r_m64_pro_1_1_font_mgr.html", "class_c_r_m64_pro_1_1_font_mgr" ],
      [ "GFX", "class_c_r_m64_pro_1_1_g_f_x.html", "class_c_r_m64_pro_1_1_g_f_x" ],
      [ "Physics", "class_c_r_m64_pro_1_1_physics.html", "class_c_r_m64_pro_1_1_physics" ],
      [ "Widget", "class_c_r_m64_pro_1_1_widget.html", "class_c_r_m64_pro_1_1_widget" ],
      [ "Panel", "class_c_r_m64_pro_1_1_panel.html", "class_c_r_m64_pro_1_1_panel" ],
      [ "Console", "class_c_r_m64_pro_1_1_console.html", "class_c_r_m64_pro_1_1_console" ],
      [ "DebugWindow", "class_c_r_m64_pro_1_1_debug_window.html", "class_c_r_m64_pro_1_1_debug_window" ],
      [ "GUIMgr", "class_c_r_m64_pro_1_1_g_u_i_mgr.html", "class_c_r_m64_pro_1_1_g_u_i_mgr" ],
      [ "SceneCameraParams", "struct_c_r_m64_pro_1_1_scene_camera_params.html", "struct_c_r_m64_pro_1_1_scene_camera_params" ],
      [ "SceneLayerContext", "struct_c_r_m64_pro_1_1_scene_layer_context.html", "struct_c_r_m64_pro_1_1_scene_layer_context" ],
      [ "SceneLayer", "class_c_r_m64_pro_1_1_scene_layer.html", "class_c_r_m64_pro_1_1_scene_layer" ],
      [ "SceneLayerTile", "class_c_r_m64_pro_1_1_scene_layer_tile.html", "class_c_r_m64_pro_1_1_scene_layer_tile" ],
      [ "SceneShapeData", "struct_c_r_m64_pro_1_1_scene_shape_data.html", "struct_c_r_m64_pro_1_1_scene_shape_data" ],
      [ "SceneObjectTrigger", "struct_c_r_m64_pro_1_1_scene_object_trigger.html", "struct_c_r_m64_pro_1_1_scene_object_trigger" ],
      [ "SceneTriggerEvent", "struct_c_r_m64_pro_1_1_scene_trigger_event.html", "struct_c_r_m64_pro_1_1_scene_trigger_event" ],
      [ "ISceneObjectFactory", "class_c_r_m64_pro_1_1_i_scene_object_factory.html", "class_c_r_m64_pro_1_1_i_scene_object_factory" ],
      [ "SceneObject", "class_c_r_m64_pro_1_1_scene_object.html", "class_c_r_m64_pro_1_1_scene_object" ],
      [ "SceneLayerObject", "class_c_r_m64_pro_1_1_scene_layer_object.html", "class_c_r_m64_pro_1_1_scene_layer_object" ],
      [ "SceneLayerImage", "class_c_r_m64_pro_1_1_scene_layer_image.html", "class_c_r_m64_pro_1_1_scene_layer_image" ],
      [ "Scene", "class_c_r_m64_pro_1_1_scene.html", "class_c_r_m64_pro_1_1_scene" ],
      [ "SceneMgr", "class_c_r_m64_pro_1_1_scene_mgr.html", "class_c_r_m64_pro_1_1_scene_mgr" ],
      [ "NetTCP", "class_c_r_m64_pro_1_1_net_t_c_p.html", "class_c_r_m64_pro_1_1_net_t_c_p" ]
    ] ]
];
